//---------------------------------------------------------------------------
#ifndef StatusFrmH
#define StatusFrmH
//---------------------------------------------------------------------------
#include <Classes.hpp>
#include <Controls.hpp>
#include <StdCtrls.hpp>
#include <Forms.hpp>
#include <ExtCtrls.hpp>
//#include <NMFtp.hpp>
#include "MainFrm.h"
#include <ComCtrls.hpp>
//#include "IdBaseComponent.hpp"
//#include "IdComponent.hpp"
//#include "IdFTP.hpp"
//#include "IdTCPClient.hpp"
//#include "IdTCPConnection.hpp"
//---------------------------------------------------------------------------

class TStatusForm : public TForm {
__published:	// IDE-managed Components
	TPanel *Panel1;
	TPanel *Panel2;
	TButton *Button1;
	TPanel *statusBar;
	TPanel *Panel3;
	TPanel *actionBar;
	TPanel *Panel4;
	TPanel *Panel5;
	TProgressBar *fileProgress;
	TProgressBar *totalProgress;
	void __fastcall FormShow(TObject *Sender);
	void __fastcall Cleanup(TObject *Sender);
	void __fastcall FormClose(TObject *Sender, TCloseAction &Action);
	void __fastcall Button1Click(TObject *Sender);
//	void __fastcall ftpConWork(TObject *Sender, TWorkMode AWorkMode,
//		const int AWorkCount);
private:	// User declarations
	class TFTPThread : public TThread {
		InstallSource *is;
		SWBuf src;
		SWBuf dest;
		SWBuf suffix;
		bool dirTransfer;
	protected:
		void __fastcall Execute();
	public:
//		TNMFTP *FTPLink;
		__fastcall TFTPThread(InstallSource *iis, const char *isrc, const char *idest, bool idirTransfer = false, bool CreateSuspended = false, const char *suffix = "");
		__fastcall TFTPThread::~TFTPThread();
		void __fastcall FTPLinkPacketRecvd(TObject *Sender);
		void __fastcall CreateFTPObject(void);
		void __fastcall PreConnect(void);
//		void __fastcall Cleanup(void);
	} *ftpThread;
public:		// User declarations
	void __fastcall PreDownload1(void);
	void __fastcall PreDownload2(void);
	long completedBytes;
	long totalBytes;
	InstallSource *is;
	SWBuf src;
	SWBuf dest;
	SWBuf suffix;
	SWBuf buffer;
	SWBuf buffer2;
	bool dirTransfer;
	void __fastcall UpdateBytes();
	__fastcall TStatusForm(TComponent* Owner);
	__fastcall ~TStatusForm();
};
//---------------------------------------------------------------------------
extern PACKAGE TStatusForm *StatusForm;
//---------------------------------------------------------------------------
#endif
